Module handler

Module handler 

ZLayer Plugin System - Plugin Interface

This interface defines what plugins must export to be loaded and executed by the ZLayer runtime. Plugins implement the handler interface to process requests. The main plugin handler interface that plugins must export

Enums

InitError
Plugin initialization error

Traits

Guest

Type Aliases

Capabilities
HandleResult
PluginInfo
PluginRequest