ZLayer Plugin System - Plugin Interface
This interface defines what plugins must export to be loaded and executed by the ZLayer runtime. Plugins implement the handler interface to process requests. The main plugin handler interface that plugins must export
Enums
- Init
Error - Plugin initialization error